# Changelog

<!--next-version-placeholder-->

## v1.3.0 (2022-10-08)


## v1.2.0 (2022-10-08)
### Fix
* Add config to readthedocas.yml ([`b600dfb`](https://github.com/Stephen-RA-King/pizazz/commit/b600dfb8c33088a91e36f617a7eaa06608091b5a))

## v1.1.0 (2022-10-08)

### Fix

- Add config to readthedocas.yml ([`b600dfb`](https://github.com/Stephen-RA-King/pizazz/commit/b600dfb8c33088a91e36f617a7eaa06608091b5a))

## 1.0.2 (2022-05-22)

### First Release of 'pizazz'

<!-- Markdown link & img dfn's -->

[github](https://github.com/Stephen-RA-King/pizazz)
